==> egc-0.1.1.tar.gz: egc-0.1.1/README.md <==
# EAGLEGraphClustering <!-- omit in toc -->

A benchmark of community detection algorithms from EAGLE-Lab, ZJU

- [Usage](#usage)
- [Datasets](#datasets)
- [Implemented baseline methods](#implemented-baseline-methods)
  - [Disjoint](#disjoint)
    - [Unsupervised Graph Neural Networks + Kmeans](#unsupervised-graph-neural-networks--kmeans)
    - [End-to-End Community Detection](#end-to-end-community-detection)
  - [Overlapping](#overlapping)
- [Installation](#installation)
- [Requirements](#requirements)

## Usage

Run any supported model by :

```shell
$ python train.py ${OPTIONAL global args} ${POSITIONAL args (model)} ${optional model args}
```

- *OPTIONAL* global args which should be used before `${model}`
  | global args    | description                     |
  | -------------- | ------------------------------- |
  | -h, --help     | show this help message and exit |
  | --dataset      | Dataset used in the experiment  |
  | --gpu          | ID of gpu used by cuda          |
  | --dir          | Path to store the dataset       |
  | --seed         | Random seed. Defaults to 4096.  |
  | --not_set_seed | Force Not to Use Random Seed.   |
- *POSITIONAL* args, i.e., all models supported
  | positional args<br/> (models supported) | description                                  |
  | --------------------------------------- | -------------------------------------------- |
  | pca_kmeans                              | run community detection on PCA with kmeans   |
  | SDCN                                    | run community detection on SDCN              |
  | DANMF                                   | run community detection on DANMF             |
  | MNMF                                    | run community detection on MNMF              |
  | gae_kmeans                              | run community detection on GAE with Kmeans   |
  | vgae_kmeans                             | run community detection on VGAE with Kmeans  |
  | VGAECD                                  | run community detection on VGAECD            |
  | dgi_kmeans                              | run community detection on DGI with Kmeans   |
  | gmi_kmeans                              | run community detection on GMI with Kmeans   |
  | SENet_kmeans                            | run community detection on SENet with Kmeans |
  | DFCN                                    | run community detection on DFCN              |
  | CommunityGAN                            | run community detection on CommunityGAN      |
  | ComE                                    | run community detection on ComE              |

e.g.,

```shell
$ python train.py --dataset=Cora gmi_kmeans --l2_coef=0.0
```

Check all optional args of a model by `python train.py ${model} -h`.

## Datasets

- `Cora`, `Citeseer`, `Pubmed` come from [DGL Lib](https://docs.dgl.ai/api/python/dgl.data.html)
- `BlogCatalog`, `Flickr` come from [CoLA github](https://github.com/GRAND-Lab/CoLA/tree/main/raw_dataset)
- `ACM` come from [SDCN github](https://github.com/bdy9527/SDCN)
- All above datasets are converted to undirected graphs.

|   Dataset   | Nodes | Edges  | Attributes | Classes |
| :---------: | :---: | :----: | :--------: | :-----: |
|    Cora     | 2708  | 10556  |    1433    |    7    |
|  Citeseer   | 3327  |  9228  |    3703    |    6    |
|   Pubmed    | 19717 | 88651  |    500     |    3    |
| BlogCatalog | 5196  | 343486 |    8189    |    6    |
|   Flickr    | 7575  | 479476 |   12047    |    9    |
|     ACM     | 3025  | 26256  |    1870    |    3    |
|  CoraFull   | 19793 | 126842 |    8710    |   70    |

## Implemented baseline methods

### Disjoint

#### Unsupervised Graph Neural Networks + Kmeans

|  method   |   Conf/Journal    |          Original Code           | Supproted |
| :-------: | :---------------: | :------------------------------: | :-------: |
|  [VGAE]   |      16nips       | [TensorFlow][vgae in tensorflow] |     ✅     |
| GraphSAGE |                   |                                  |           |
|   [DGI]   |      19iclr       |    [Pytorch][dgi in pytorch]     |     ✅     |
|   [GMI]   |       20www       |    [Pytorch][gmi in pytorch]     |     ✅     |
|  [SENet]  | 21Neural Networks |                                  |     ✅     |

#### End-to-End Community Detection

|  method  | Conf/Journal |       Original Code        | Supproted |
| :------: | :----------: | :------------------------: | :-------: |
|  [SDCN]  |    20www     | [Pytorch][sdcn in pytorch] |     ✅     |
| [DANMF]  |    18cikm    |     [code][danmf code]     |     ✅     |
| [M-NMF]  |    17aaai    | [Matlab][m-nmf in matlab]  |     ✅     |
|  [DFCN]  |    21aaai    | [Pytorch][dfcn in pytorch] |     ✅     |
| [VGAECD] |    18icdm    |             --             |     ✅     |
|  [ComE]  |    17cikm    |     [code][come code]      |     ✅     |
| [DAEGC]  |   19ijcai    |  [code][daegc in pytorch]  |     ✅     |

### Overlapping

|     method     | Conf/Journal |              Original Code               | Supproted |
| :------------: | :----------: | :--------------------------------------: | :-------: |
| [CommunityGAN] |    19www     | [TensorFlow][communitygan in tensorflow] |     ✅     |

## Installation

```bash
# NOTE: python>=3.8 is needed
# Install cuda if necessary. Check Cuda version first.
$ sudo bash .ci/cuda.sh
# Leave out `bash .ci/install-dev.sh &&` if no dev env is needed.
$ bash .ci/install-dev.sh && bash .ci/install.sh
# run `source .env/bin/activate` to activate the virtual env
```

## Requirements

DGL installation guide: https://www.dgl.ai/pages/start.html

torch installation guide: https://pytorch.org/get-started/locally/

- CUDA 11

```txt
python >= 3.8
cudatoolkit >= 11.1.1
torch >= 1.12.0
dgl >= 1.1.0
ogb >= 1.3.3
pylint >= 2.11.1
pre-commit >= 2.15.0
yapf >= 0.31.0
tqdm >= 4.62.3
texttable >= 1.6.4
Cython >= 0.25
```

[come]: https://dl.acm.org/doi/abs/10.1145/3132847.3132925
[come code]: https://github.com/andompesta/ComE
[communitygan]: https://arxiv.org/pdf/1901.06631.pdf
[communitygan in tensorflow]: https://github.com/SamJia/CommunityGAN
[daegc]: https://www.ijcai.org/proceedings/2019/0509.pdf
[daegc in pytorch]: https://github.com/Tiger101010/DAEGC
[danmf]: https://www.researchgate.net/profile/Chuan-Chen-11/publication/328439632_Deep_Autoencoder-like_Nonnegative_Matrix_Factorization_for_Community_Detection/links/5d7dc4b3a6fdcc2f0f6fbf3a/Deep-Autoencoder-like-Nonnegative-Matrix-Factorization-for-Community-Detection.pdf
[danmf code]: https://github.com/benedekrozemberczki/DANMF
[dfcn]: https://arxiv.org/pdf/2012.09600.pdf
[dfcn in pytorch]: https://github.com/WxTu/DFCN
[dgi]: https://arxiv.org/pdf/1809.10341.pdf
[dgi in pytorch]: https://github.com/PetarV-/DGI
[gmi]: https://arxiv.org/pdf/2002.01169.pdf
[gmi in pytorch]: https://github.com/zpeng27/GMI
[m-nmf]: https://aaai.org/ocs/index.php/AAAI/AAAI17/paper/view/14589/13763
[m-nmf in matlab]: https://github.com/AnryYang/M-NMF
[sdcn]: https://arxiv.org/pdf/2002.01633.pdf
[sdcn in pytorch]: https://github.com/bdy9527/SDCN
[senet]: https://www.sciencedirect.com/science/article/abs/pii/S0893608021002227
[vgae]: https://arxiv.org/pdf/1611.07308.pdf
[vgae in tensorflow]: https://github.com/tkipf/gae
[vgaecd]: https://sci-hub.ru/10.1109/icdm.2018.00022

==> egc-0.2.1.tar.gz: egc-0.2.1/README.md <==
# EAGLEGraphClustering <!-- omit in toc -->

<div align="center">

[![PYPI](https://img.shields.io/pypi/v/egc?style=flat)](https://pypi.org/project/egc/)
<!-- [![Latest Release](https://img.shields.io/github/v/tag/eaglelab-zju/EGC)](https://github.com/eaglelab-zju/EGC/tags) -->

</div>

A benchmark of graph clustering from [EAGLE-Lab, Zhejiang University](https://eagle.zju.edu.cn/).

- [Installation](#installation)
- [Usage](#usage)
  - [Pip Package](#pip-package)
  - [Command line](#command-line)
- [Datasets](#datasets)
- [Implemented baseline methods](#implemented-baseline-methods)
  - [Disjoint](#disjoint)
    - [Unsupervised Graph Neural Networks + Kmeans](#unsupervised-graph-neural-networks--kmeans)
    - [End-to-End Graph Clustering](#end-to-end-graph-clustering)
  - [Overlapping](#overlapping)
- [Requirements](#requirements)
- [Contributing](#contributing)

## Installation
- python>=3.8
- torch>=1.12
- dgl>=1.1

```bash
$ python -m pip install egc
```

## Usage

### Pip Package

See [egc](https://eaglelab-zju.github.io/egc_doc_repo/) for docs.

- Import the package and use any graph clustering model supported as:

```python
from torch import nn
from egc.model import DGL_GAEKmeans
from egc.utils import load_data
from egc.utils import get_default_args

# load graph
graph, label, n_clusters = load_data(
    dataset_name='Cora',
    directory='./data',
)
features = graph.ndata["feat"]
adj_csr = graph.adj_external(scipy_fmt="csr")

# get default args
args = get_default_args('gae_kmeans')

# init the model
model = DGL_GAEKmeans(
    epochs=args["epochs"],
    n_clusters=10,
    fead_dim=features.shape[1],
    n_nodes=features.shape[0],
    hidden_dim1=args["hidden1"],
    dropout=args["dropout"],
    lr=args["lr"],
    early_stop=args["early_stopping_epoch"],
    activation=args["activation"],
)

# fit the model
model.fit(adj_csr, features)

# get clustering results
res = model.get_memberships()
```

### Command line

- Clone the Repo
- Install the env

```bash
# NOTE: python>=3.8 is needed
# Install cuda if necessary. Check Cuda version first.
$ cd EGC
# Leave out `bash .ci/install-dev.sh &&` if no dev env is needed.
$ bash .ci/install-dev.sh && bash .ci/install.sh
# run `source .env/bin/activate` to activate the virtual env
```

- Run any supported model as:

```shell
$ python train.py ${OPTIONAL global args} ${POSITIONAL args (model)} ${optional model args}
```

- *OPTIONAL* global args which should be used before `${model}`
- *POSITIONAL* args, i.e., all models supported

E.g.,

```bash
# check OPTIONAL global args, e.g., all models supported
$ python train.py -h

# check optional args of certain model
$ python train.py gae_kmeans -h

# run any model
$ python train.py --dataset=Cora gae_kmeans --lr 0.001
```

## Datasets

- `Cora`, `Citeseer`, `Pubmed` come from [DGL Lib](https://docs.dgl.ai/api/python/dgl.data.html)
- `BlogCatalog`, `Flickr` come from [CoLA github](https://github.com/GRAND-Lab/CoLA/tree/main/raw_dataset)
- `ACM` come from [SDCN github](https://github.com/bdy9527/SDCN)
- All above datasets are converted to undirected graphs.

|   Dataset   |  Nodes |   Edges | Attributes | Classes |
| :---------: | -----: | ------: | ---------: | ------: |
|    Cora     |  2,708 |  10,556 |      1,433 |       7 |
|  Citeseer   |  3,327 |   9,228 |      3,703 |       6 |
|   Pubmed    | 19,717 |  88,651 |        500 |       3 |
| BlogCatalog |  5,196 | 343,486 |      8,189 |       6 |
|   Flickr    |  7,575 | 479,476 |     12,047 |       9 |
|     ACM     |  3,025 |  26,256 |      1,870 |       3 |
|  CoraFull   | 19,793 | 126,842 |      8,710 |      70 |

## Implemented baseline methods

### Disjoint

#### Unsupervised Graph Neural Networks + Kmeans

|  method   |   Conf/Journal    |          Original Code           | Supproted |
| :-------: | :---------------: | :------------------------------: | :-------: |
|  [VGAE]   |      16nips       | [TensorFlow][vgae in tensorflow] |     ✅     |
| GraphSAGE |                   |                                  |           |
|   [DGI]   |      19iclr       |    [Pytorch][dgi in pytorch]     |     ✅     |
|   [GMI]   |       20www       |    [Pytorch][gmi in pytorch]     |     ✅     |
|  [SENet]  | 21Neural Networks |                                  |     ✅     |

#### End-to-End Graph Clustering

|  method  | Conf/Journal |       Original Code        | Supproted |
| :------: | :----------: | :------------------------: | :-------: |
|  [SDCN]  |    20www     | [Pytorch][sdcn in pytorch] |     ✅     |
| [DANMF]  |    18cikm    |     [code][danmf code]     |     ✅     |
| [M-NMF]  |    17aaai    | [Matlab][m-nmf in matlab]  |     ✅     |
|  [DFCN]  |    21aaai    | [Pytorch][dfcn in pytorch] |     ✅     |
| [VGAECD] |    18icdm    |             --             |     ✅     |
|  [ComE]  |    17cikm    |     [code][come code]      |     ✅     |
| [DAEGC]  |   19ijcai    |  [code][daegc in pytorch]  |     ✅     |

### Overlapping

|     method     | Conf/Journal |              Original Code               | Supproted |
| :------------: | :----------: | :--------------------------------------: | :-------: |
| [CommunityGAN] |    19www     | [TensorFlow][communitygan in tensorflow] |     ✅     |

## Requirements

See [dependencies](./pyproject.toml), [requirements-dev.txt](./requirements-dev.txt) and [requirements.txt](./requirements.txt).

## Contributing
See [CONTRIBUTING.md](./CONTRIBUTING.md).

[come]: https://dl.acm.org/doi/abs/10.1145/3132847.3132925
[come code]: https://github.com/andompesta/ComE
[communitygan]: https://arxiv.org/pdf/1901.06631.pdf
[communitygan in tensorflow]: https://github.com/SamJia/CommunityGAN
[daegc]: https://www.ijcai.org/proceedings/2019/0509.pdf
[daegc in pytorch]: https://github.com/Tiger101010/DAEGC
[danmf]: https://www.researchgate.net/profile/Chuan-Chen-11/publication/328439632_Deep_Autoencoder-like_Nonnegative_Matrix_Factorization_for_Community_Detection/links/5d7dc4b3a6fdcc2f0f6fbf3a/Deep-Autoencoder-like-Nonnegative-Matrix-Factorization-for-Community-Detection.pdf
[danmf code]: https://github.com/benedekrozemberczki/DANMF
[dfcn]: https://arxiv.org/pdf/2012.09600.pdf
[dfcn in pytorch]: https://github.com/WxTu/DFCN
[dgi]: https://arxiv.org/pdf/1809.10341.pdf
[dgi in pytorch]: https://github.com/PetarV-/DGI
[gmi]: https://arxiv.org/pdf/2002.01169.pdf
[gmi in pytorch]: https://github.com/zpeng27/GMI
[m-nmf]: https://aaai.org/ocs/index.php/AAAI/AAAI17/paper/view/14589/13763
[m-nmf in matlab]: https://github.com/AnryYang/M-NMF
[sdcn]: https://arxiv.org/pdf/2002.01633.pdf
[sdcn in pytorch]: https://github.com/bdy9527/SDCN
[senet]: https://www.sciencedirect.com/science/article/abs/pii/S0893608021002227
[vgae]: https://arxiv.org/pdf/1611.07308.pdf
[vgae in tensorflow]: https://github.com/tkipf/gae
[vgaecd]: https://sci-hub.ru/10.1109/icdm.2018.00022
